==> ogre-13.5.2.tar.gz: ogre-13.5.2/RenderSystems/Vulkan/include/OgreVulkanTextureGpuWindow.h <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
    (Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-present Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/

#ifndef _OgreVulkanTextureGpuWindow_H_
#define _OgreVulkanTextureGpuWindow_H_

#include "OgreVulkanTextureGpu.h"

#include "OgreHeaderPrefix.h"

namespace Ogre
{
    class _OgreVulkanExport VulkanTextureGpuWindow : public VulkanTextureGpu
    {
        VulkanWindow *mWindow;
        uint32 mCurrentImageIdx;

        void createInternalResourcesImpl( void ) override;
        void freeInternalResourcesImpl( void ) override;

    public:
        VulkanTextureGpuWindow(String name, TextureType initialType, TextureManager* textureManager,
                               VulkanWindow* window);
        virtual ~VulkanTextureGpuWindow();

        bool isRenderWindowSpecific() const override { return true; }

        /// @copydoc VulkanWindow::getImageAcquiredSemaphore
        VkSemaphore getImageAcquiredSemaphore( void );

        void _setCurrentImage( VkImage image, uint32 imageIdx );
        uint32 getCurrentImageIdx( void ) const { return mCurrentImageIdx; }

        VulkanWindow* getWindow() const { return mWindow; }

        void getCustomAttribute( const String& name, void *pData ) override;
    };
}  // namespace Ogre

#include "OgreHeaderSuffix.h"

#endif

==> ogre-14.3.4.tar.gz: ogre-14.3.4/RenderSystems/Vulkan/include/OgreVulkanTextureGpuWindow.h <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
    (Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-present Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/

#ifndef _OgreVulkanTextureGpuWindow_H_
#define _OgreVulkanTextureGpuWindow_H_

#include "OgreVulkanTextureGpu.h"

#include "OgreHeaderPrefix.h"

namespace Ogre
{
    class _OgreVulkanExport VulkanTextureGpuWindow : public VulkanTextureGpu
    {
        VulkanWindow *mWindow;
        uint32 mCurrentImageIdx;

        void createInternalResourcesImpl( void ) override;
        void freeInternalResourcesImpl( void ) override;

    public:
        VulkanTextureGpuWindow(const String& name, TextureType initialType, TextureManager* textureManager,
                               VulkanWindow* window);
        virtual ~VulkanTextureGpuWindow();

        bool isRenderWindowSpecific() const override { return true; }

        /// @copydoc VulkanWindow::getImageAcquiredSemaphore
        VkSemaphore getImageAcquiredSemaphore( void );

        void _setCurrentImage( VkImage image, uint32 imageIdx );
        uint32 getCurrentImageIdx( void ) const { return mCurrentImageIdx; }

        VulkanWindow* getWindow() const { return mWindow; }

        void getCustomAttribute( const String& name, void *pData ) override;
    };
}  // namespace Ogre

#include "OgreHeaderSuffix.h"

#endif
